@@ -16,20 +16,20 @@ import (
 type Run struct {
 	state *state.HelmState
 	helm  helmexec.Interface
-	ctx   Context
+	ctx   *Context
 
 	ReleaseToChart map[state.PrepareChartKey]string
 
 	Ask func(string) bool
 }
 
-func NewRun(st *state.HelmState, helm helmexec.Interface, ctx Context) (*Run, error) {
+func NewRun(st *state.HelmState, helm helmexec.Interface, ctx *Context) (*Run, error) {
 	if helm == nil {
 		return nil, fmt.Errorf("Assertion failed: helmexec.Interface must not be nil")
 	}
 
-	if !helm.IsHelm3() {
-		return nil, fmt.Errorf("helmfile has deprecated helm2 since v0.150.0")
+	if !helm.IsHelm3() && !helm.IsHelm4() {
+		return nil, fmt.Errorf("helmfile requires helm 3.x or 4.x")
 	}
 
 	return &Run{state: st, helm: helm, ctx: ctx}, nil
@@ -62,7 +62,13 @@ func (r *Run) withPreparedCharts(helmfileCommand string, opts state.ChartPrepare
 		panic("Run.PrepareCharts can be called only once")
 	}
 
-	if !opts.SkipRepos {
+	// Check both CLI options and helmDefaults for skipping repos (issue #2296)
+	// Both skipDeps and skipRefresh cause repo sync to be skipped because:
+	// - skipRefresh explicitly means "don't update repos"
+	// - skipDeps implies "I have all dependencies locally" which means repo data isn't needed
+	// This matches the CLI behavior where --skip-deps and --skip-refresh both skip repo operations.
+	skipRepos := opts.SkipRepos || r.state.HelmDefaults.SkipDeps || r.state.HelmDefaults.SkipRefresh
+	if !skipRepos {
 		ctx := r.ctx
 		if err := ctx.SyncReposOnce(r.state, r.helm); err != nil {
 			return err
@@ -120,7 +126,10 @@ func (r *Run) withPreparedCharts(helmfileCommand string, opts state.ChartPrepare
 }
 
 func (r *Run) Deps(c DepsConfigProvider) []error {
-	if !c.SkipRepos() {
+	// Check both CLI options and helmDefaults for skipping repos (issue #2296)
+	// Both skipDeps and skipRefresh cause repo sync to be skipped (see withPreparedCharts for rationale)
+	skipRepos := c.SkipRepos() || r.state.HelmDefaults.SkipDeps || r.state.HelmDefaults.SkipRefresh
+	if !skipRepos {
 		if err := r.ctx.SyncReposOnce(r.state, r.helm); err != nil {
 			return []error{err}
 		}
