@@ -224,33 +224,40 @@ func typedVal(val string, st bool) any {
 	return val
 }
 
-func MergeMaps(a, b map[string]interface{}) map[string]interface{} {
+// MergeMaps merges two maps with special handling for nested maps and arrays.
+func MergeMaps(a, b map[string]interface{}, opts ...MergeOptions) map[string]interface{} {
+	arrayStrategy := ArrayMergeStrategySparse
+	if len(opts) > 0 {
+		arrayStrategy = opts[0].ArrayStrategy
+	}
+
 	out := make(map[string]interface{}, len(a))
-	// fill the out map with the first map
 	for k, v := range a {
 		out[k] = v
 	}
 	for k, v := range b {
 		if v == nil {
+			// If key doesn't exist in base, add nil (issue #1154).
+			// If key exists in base, don't overwrite with nil.
+			if _, exists := out[k]; !exists {
+				out[k] = nil
+			}
 			continue
 		}
 		if v, ok := v.(map[string]interface{}); ok {
 			if bv, ok := out[k]; ok {
 				if bv, ok := bv.(map[string]interface{}); ok {
-					// if b and out map has a map value, merge it too
-					out[k] = MergeMaps(bv, v)
+					out[k] = MergeMaps(bv, v, opts...)
 					continue
 				}
 			}
 		}
-		// Handle array merging element-by-element
 		vSlice := toInterfaceSlice(v)
 		if vSlice != nil {
 			if outVal, exists := out[k]; exists {
 				outSlice := toInterfaceSlice(outVal)
 				if outSlice != nil {
-					// Both are slices - merge element by element
-					out[k] = mergeSlices(outSlice, vSlice)
+					out[k] = mergeSlices(outSlice, vSlice, arrayStrategy)
 					continue
 				}
 			}
@@ -260,7 +267,6 @@ func MergeMaps(a, b map[string]interface{}) map[string]interface{} {
 	return out
 }
 
-// toInterfaceSlice converts various slice types to []interface{}
 func toInterfaceSlice(v any) []any {
 	if slice, ok := v.([]any); ok {
 		return slice
@@ -268,41 +274,82 @@ func toInterfaceSlice(v any) []any {
 	return nil
 }
 
-// mergeSlices merges two slices element by element
-// Elements from override (b) take precedence, but we preserve elements from base (a)
-// that don't exist in override
-func mergeSlices(base, override []any) []any {
-	// Determine the maximum length
+type ArrayMergeStrategy int
+
+const (
+	// ArrayMergeStrategySparse uses auto-detection: sparse arrays (with nils) merge
+	// element-by-element, complete arrays (no nils) replace entirely.
+	ArrayMergeStrategySparse ArrayMergeStrategy = iota
+	// ArrayMergeStrategyReplace always replaces arrays entirely.
+	ArrayMergeStrategyReplace
+	// ArrayMergeStrategyMerge always merges arrays element-by-element (for CLI overrides).
+	ArrayMergeStrategyMerge
+)
+
+type MergeOptions struct {
+	ArrayStrategy ArrayMergeStrategy
+}
+
+// mergeSlices merges two slices based on the strategy.
+//
+// Behavior by strategy:
+//   - ArrayMergeStrategyReplace: always returns override as-is
+//   - ArrayMergeStrategySparse: auto-detects based on nil values (see below)
+//   - ArrayMergeStrategyMerge: always merges element-by-element
+//
+// For Sparse strategy, auto-detection logic:
+//   - If override contains ANY nil values → treated as sparse → merge element-by-element
+//   - If override contains NO nil values → treated as complete → replace entirely
+//
+// Edge cases:
+//   - Empty array `[]` has no nils, so it replaces entirely. This is intentional:
+//     explicitly setting an empty array should clear the base array.
+//   - Explicit `[null, value]` in YAML is treated as sparse (rare but correct).
+//
+// Recursive behavior: When merging maps within array elements, the same strategy
+// is propagated to nested MergeMaps calls, maintaining consistent merge semantics.
+func mergeSlices(base, override []any, strategy ArrayMergeStrategy) []any {
+	if strategy == ArrayMergeStrategyReplace {
+		return override
+	}
+
+	if strategy == ArrayMergeStrategySparse {
+		isSparse := false
+		for _, v := range override {
+			if v == nil {
+				isSparse = true
+				break
+			}
+		}
+		if !isSparse {
+			return override
+		}
+	}
+
+	// Merge element-by-element (for ArrayMergeStrategyMerge or sparse arrays)
 	maxLen := len(base)
 	if len(override) > maxLen {
 		maxLen = len(override)
 	}
 
 	result := make([]interface{}, maxLen)
-
-	// First copy all elements from base
 	copy(result, base)
 
-	// Then merge/override with elements from override
 	for i := 0; i < len(override); i++ {
 		overrideVal := override[i]
-
-		// Skip nil values in override - they represent unset indices
 		if overrideVal == nil {
 			continue
 		}
 
-		// If both are maps, merge them recursively
 		if overrideMap, ok := overrideVal.(map[string]any); ok {
 			if i < len(base) {
 				if baseMap, ok := base[i].(map[string]any); ok {
-					result[i] = MergeMaps(baseMap, overrideMap)
+					result[i] = MergeMaps(baseMap, overrideMap, MergeOptions{ArrayStrategy: strategy})
 					continue
 				}
 			}
 		}
 
-		// Otherwise, override completely
 		result[i] = overrideVal
 	}
 
