@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"regexp"
 	"strings"
 )
 
@@ -71,3 +72,10 @@ func getBuildDepsFlags(cpr *chartPrepareResult) []string {
 
 	return flags
 }
+
+// safePath returns a clean path
+func safeVersionPath(version string) string {
+	c := regexp.MustCompile(`=|>|<|!|\||~|\^| |,|\*`)
+	sp := c.ReplaceAll([]byte(version), []byte("_"))
+	return string(sp)
+}
